pub enum StateToDynGroundError {
UndefinedSpheroid(DynOrigin),
FromBodyFixed(FromBodyFixedError),
NonBodyFixedFrame(String),
}Expand description
Errors that can occur when converting a dynamic Cartesian orbit to a ground location.
Variants
UndefinedSpheroid(DynOrigin)
The origin body does not define equatorial radius and flattening.
FromBodyFixed(FromBodyFixedError)
Failed to convert from body-fixed coordinates.
NonBodyFixedFrame(String)
The frame is not a body-fixed frame.