pub struct GroundLocation<B: TrySpheroid> { /* private fields */ }Expand description
A location on the surface of a celestial body.
Implementations
Sourceimpl<B: Spheroid> GroundLocation<B>
Infallible constructor — requires compile-time Spheroid guarantee.
impl<B: Spheroid> GroundLocation<B>
Infallible constructor — requires compile-time Spheroid guarantee.
Sourceimpl<B: TrySpheroid> GroundLocation<B>
Fallible constructor — for DynOrigin and other TrySpheroid types.
impl<B: TrySpheroid> GroundLocation<B>
Fallible constructor — for DynOrigin and other TrySpheroid types.
Sourceimpl<B: TrySpheroid + Into<DynOrigin>> GroundLocation<B>
impl<B: TrySpheroid + Into<DynOrigin>> GroundLocation<B>
Sourcepub fn into_dyn(self) -> DynGroundLocation
pub fn into_dyn(self) -> DynGroundLocation
Converts the ground location into a dynamic representation.
Sourceimpl<B: TrySpheroid> GroundLocation<B>
impl<B: TrySpheroid> GroundLocation<B>
Sourcepub fn coordinates(&self) -> LonLatAlt
pub fn coordinates(&self) -> LonLatAlt
Returns the geodetic coordinates.
Sourcepub fn body_fixed_position(&self) -> DVec3
pub fn body_fixed_position(&self) -> DVec3
Returns the body-fixed Cartesian position in meters.
Sourcepub fn rotation_to_topocentric(&self) -> DMat3
pub fn rotation_to_topocentric(&self) -> DMat3
Returns the rotation matrix from body-fixed to topocentric (SEZ) frame.
Sourcepub fn compute_observables(
&self,
state_position: DVec3,
state_velocity: DVec3,
) -> Observables
pub fn compute_observables( &self, state_position: DVec3, state_velocity: DVec3, ) -> Observables
Computes topocentric observables from raw body-fixed position and velocity vectors.
Sourcepub fn observables<T: TimeScale + Copy>(
&self,
state: CartesianOrbit<T, B, Iau<B>>,
) -> Observableswhere
B: RotationalElements + Copy,
pub fn observables<T: TimeScale + Copy>(
&self,
state: CartesianOrbit<T, B, Iau<B>>,
) -> Observableswhere
B: RotationalElements + Copy,
Computes topocentric observables from a Cartesian orbit in the body-fixed frame.
Sourcepub fn observables_dyn(&self, state: DynCartesianOrbit) -> Observables
pub fn observables_dyn(&self, state: DynCartesianOrbit) -> Observables
Computes topocentric observables from a dynamic Cartesian orbit.